==> OWL-DirectSemantics-0.000_03.tar.gz: OWL-DirectSemantics-0.000_03/lib/OWL/DirectSemantics/Element/Annotation.pm <==
package OWL::DirectSemantics::Element::Annotation;

BEGIN {
	$OWL::DirectSemantics::Element::Annotation::AUTHORITY = 'cpan:TOBYINK';
	$OWL::DirectSemantics::Element::Annotation::VERSION   = '0.000_03';
};

use 5.008;





use Moose;

extends 'OWL::DirectSemantics::Element';
with 'OWL::DirectSemantics::Writer::Dump';
with 'OWL::DirectSemantics::Writer::FunctionalSyntax';

has 'source'   => (is => 'rw', isa => 'RDF::Trine::Node');
has 'property' => (is => 'rw', isa => 'RDF::Trine::Node', required=>1);
has 'target'   => (is => 'rw', isa => 'RDF::Trine::Node', required=>1);

sub fs_arguments { return ($_[0]->property, $_[0]->target); }

1;

__END__

=head1 NAME

OWL::DirectSemantics::Element::Annotation - represents an OWL Annotation

=head1 DESCRIPTION

This class represents the Annotation element in OWL Direct Semantics.

This class inherits from OWL::DirectSemantics::Element.

It does the OWL::DirectSemantics::Writer::FunctionalSyntax and
OWL::DirectSemantics::Writer::Dump roles.

=head2 Attributes

=over

=item C<< annotations >>

A list of annotations associated with this object.
The value is a ArrayRef.

=item C<< property >>

The property.
The value is a RDF::Trine::Node.
This is a required attribute.

=item C<< source >>

This is used pretty inconsistently. Don't rely on it.
The value is a RDF::Trine::Node.

=item C<< target >>

The object/target/value of the annotation.
The value is a RDF::Trine::Node.
This is a required attribute.



=back

=head1 SEE ALSO

L<OWL::DirectSemantics>,
L<OWL::DirectSemantics::Element>.

=head1 AUTHOR

Toby Inkster E<lt>tobyink@cpan.orgE<gt>.

=head1 COPYRIGHT

Copyright 2011-2012 Toby Inkster

This library is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=head1 DISCLAIMER OF WARRANTIES

THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

==> OWL-DirectSemantics-0.001.tar.gz: OWL-DirectSemantics-0.001/lib/OWL/DirectSemantics/Element/Annotation.pm <==
package OWL::DirectSemantics::Element::Annotation;

BEGIN {
	$OWL::DirectSemantics::Element::Annotation::AUTHORITY = 'cpan:TOBYINK';
	$OWL::DirectSemantics::Element::Annotation::VERSION   = '0.001';
};

use 5.008;





use Moose;

extends 'OWL::DirectSemantics::Element';
with 'OWL::DirectSemantics::Writer::Dump';
with 'OWL::DirectSemantics::Writer::FunctionalSyntax';

has 'source'   => (is => 'rw', isa => 'RDF::Trine::Node');
has 'property' => (is => 'rw', isa => 'RDF::Trine::Node', required=>1);
has 'target'   => (is => 'rw', isa => 'RDF::Trine::Node', required=>1);

sub fs_arguments { return ($_[0]->property, $_[0]->target); }

1;

__END__

=head1 NAME

OWL::DirectSemantics::Element::Annotation - represents an OWL Annotation

=head1 DESCRIPTION

This class represents the Annotation element in OWL Direct Semantics.

This class inherits from OWL::DirectSemantics::Element.

It does the OWL::DirectSemantics::Writer::FunctionalSyntax and
OWL::DirectSemantics::Writer::Dump roles.

=head2 Attributes

=over

=item C<< annotations >>

A list of annotations associated with this object.
The value is a ArrayRef.

=item C<< property >>

The property.
The value is a RDF::Trine::Node.
This is a required attribute.

=item C<< source >>

This is used pretty inconsistently. Don't rely on it.
The value is a RDF::Trine::Node.

=item C<< target >>

The object/target/value of the annotation.
The value is a RDF::Trine::Node.
This is a required attribute.



=back

=head1 SEE ALSO

L<OWL::DirectSemantics>,
L<OWL::DirectSemantics::Element>.

=head1 AUTHOR

Toby Inkster E<lt>tobyink@cpan.orgE<gt>.

=head1 COPYRIGHT

Copyright 2011-2012 Toby Inkster

This library is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=head1 DISCLAIMER OF WARRANTIES

THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
